#[non_exhaustive]pub struct BenchmarkCaseIdentity {
pub group: String,
pub name: String,
pub kind: BenchmarkKind,
pub throughput: Throughput,
pub measurement_domain: MeasurementDomain,
pub pmu_scope: PmuScope,
pub pmu_counter_profile: PmuCounterProfile,
pub energy_scope: EnergyScope,
pub memory_bandwidth_scope: MemoryBandwidthScope,
pub metadata: BTreeMap<String, String>,
}Expand description
Stable semantic identity for one native benchmark case.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.group: Stringname: Stringkind: BenchmarkKindthroughput: Throughputmeasurement_domain: MeasurementDomainpmu_scope: PmuScopePMU thread scope. This prevents calling-thread and process-thread evidence from being treated as the same benchmark case.
pmu_counter_profile: PmuCounterProfileCPU event profile. Full and compact counter evidence is collected under different multiplexing conditions and is not comparison-compatible.
energy_scope: EnergyScopeSystem energy scope. Package-wide RAPL evidence is not equivalent to a run that did not collect system energy.
memory_bandwidth_scope: MemoryBandwidthScopeSystem-wide IMC coverage. Missing, partial, and complete memory bandwidth evidence are intentionally different identities.
metadata: BTreeMap<String, String>Trait Implementations
Sourceimpl Clone for BenchmarkCaseIdentity
impl Clone for BenchmarkCaseIdentity
Sourcefn clone(&self) -> BenchmarkCaseIdentity
fn clone(&self) -> BenchmarkCaseIdentity
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BenchmarkCaseIdentity
impl Debug for BenchmarkCaseIdentity
Sourceimpl<'de> Deserialize<'de> for BenchmarkCaseIdentity
impl<'de> Deserialize<'de> for BenchmarkCaseIdentity
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for BenchmarkCaseIdentity
Sourceimpl PartialEq for BenchmarkCaseIdentity
impl PartialEq for BenchmarkCaseIdentity
Sourceimpl Serialize for BenchmarkCaseIdentity
impl Serialize for BenchmarkCaseIdentity
impl StructuralPartialEq for BenchmarkCaseIdentity